==> seclea_ai-0.0.44.tar.gz: seclea_ai-0.0.44/README.md <==
<picture><source srcset="https://github.com/seclea/seclea_ai/raw/dev/docs/media/logo-dark.png" media="(prefers-color-scheme: dark)"><img src="https://github.com/seclea/seclea_ai/raw/dev/docs/media/logo-light.png#gh-light-mode-only" height="100" alt="Seclea"><span style="display: none"><img alt="Seclea" src="https://github.com/seclea/seclea_ai/raw/dev/docs/media/logo-dark.png#gh-dark-mode-only" height="100"></span></picture>

# Seclea AI

[![pypi](https://img.shields.io/pypi/v/seclea-ai.svg)](https://pypi.python.org/pypi/wandb)

Build better models, stay compliant and manage your Data Science risks more effectively with Seclea.
We help you and your organisation to manage Data Science projects the way you want, with the tools you want, while helping
you ensure that you build safe, effective products.

[See what we can do →](https://seclea.com)

## Features

What's all the bells and whistles this project can perform?

- What's the main functionality
- You can also do another thing

## Integrate with your workflow

Get us from PyPI or conda, whatever you prefer

```shell
$ pip3 install seclea_ai
$ conda install seclea_ai
```

## Usage

Use this package to record your data science development work.

```
from seclea_ai import SecleaAI

seclea = SecleaAI(project_name="My Project", organization="My Org")
```

## Maintainers

[@rogermilroy](https://github.com/rogermilroy)

## Contributing

The best way to contribute at the moment is by giving us feedback in [Issues](https://github.com/seclea/seclea_ai/issues).
Both bug reports as well as feature requests are welcome.

In case of sensitive bugs like security vulnerabilities, please contact
security@seclea.com directly instead of using issue tracker. We value your effort
to improve the security and privacy of this project!

## License

The code in this repository is provided under the following License.

[LICENSE](https://github.com/seclea/seclea_ai/blob/dev/LICENSE.txt) © Seclea Ltd.

==> seclea_ai-0.1.0.tar.gz: seclea_ai-0.1.0/README.md <==
<picture><source srcset="https://github.com/seclea/seclea_ai/raw/dev/docs/media/logos/logo-dark.png" media="(prefers-color-scheme: dark)"><img src="https://github.com/seclea/seclea_ai/raw/dev/docs/media/logos/logo-light.png#gh-light-mode-only" height="100" alt="Seclea"><span style="display: none"><img alt="Seclea" src="https://github.com/seclea/seclea_ai/raw/dev/docs/media/logo-dark.png#gh-dark-mode-only" height="100"></span></picture>

# Seclea AI [![pypi](https://img.shields.io/pypi/v/seclea-ai.svg)](https://pypi.python.org/pypi/seclea-ai)

Build better models, stay compliant and manage your Data Science risks more effectively with Seclea.
We help you and your organisation to manage Data Science projects the way you want, with the tools you want, while helping
you ensure that you build safe, effective products.

[See what we can do →](https://seclea.com)

## Features

What's all the bells and whistles this project can perform?

- What's the main functionality
- You can also do another thing

## Integrate with your workflow

Get us from PyPI or conda, whatever you prefer

```shell
$ pip3 install seclea_ai
$ conda install seclea_ai
```

## Usage

Use this package to record your data science development work.

```
from seclea_ai import SecleaAI

seclea = SecleaAI(project_name="My Project", organization="My Org")
```

## Maintainers

[@rogermilroy](https://github.com/rogermilroy)

## Contributing

The best way to contribute at the moment is by giving us feedback in [Issues](https://github.com/seclea/seclea_ai/issues).
Both bug reports as well as feature requests are welcome.

In case of sensitive bugs like security vulnerabilities, please contact
security@seclea.com directly instead of using issue tracker. We value your effort
to improve the security and privacy of this project!

## License

The code in this repository is provided under the following License.

[LICENSE](https://github.com/seclea/seclea_ai/blob/dev/LICENSE.txt) © Seclea Ltd.
